@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigActions.php,v 1.14 2007/03/17 13:53:07 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigActions.php,v 1.15 2007/03/31 08:45:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigActions.php,v 1.14 2007/03/17 13:53:07 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigActions.php,v 1.15 2007/03/31 08:45:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigActions extends SyL_Config
@@ -244,7 +244,29 @@ XMLѡ
             if (!$name) return;
 
             switch ($current_path) {
+            case '/actions/action/setter':
+                // 쥯ȥåȥ
+                if (isset($attribute['direct']) && ($attribute['direct'] === 'true')) {
+                    // 쥯ȤξϡƬˡ_פղä
+                    $method_name = 'setter:_' . $attribute['name'] . ':true';
+                } else {
+                    $method_name = 'setter:set' . ucfirst($attribute['name']) . ':false';
+                }
+                $this->config[$name]['event'][$this->event][] = $method_name;
+                $this->config[$name]['args'][$method_name] = array();
+                break;
+
+            case '/actions/action/setter/arg':
+                $type = isset($attribute['type']) ? $attribute['type'] : 'value';
+                $ref  = (isset($attribute['reference']) && ($attribute['reference'] === 'true')) ? 'true' : 'false';
+                $this->config[$name]['args'][$method_name][] = $type . ':' . $ref . ':' . $text;
+                break;
+
             case '/actions/action/method':
+                if (isset($attribute['actions']) && !preg_match ('/^' . preg_quote($attribute['actions']) . '$/', $this->dm->getActionName())) {
+                    $method_name = '';
+                    break;
+                }
                 if (!isset($this->config[$name]['args'])) {
                     $this->config[$name]['args'] = array();
                 }
@@ -255,9 +277,11 @@ XMLѡ
                 break;
 
             case '/actions/action/method/arg':
-                $type = isset($attribute['type']) ? $attribute['type'] : 'value';
-                $ref  = (isset($attribute['reference']) && ($attribute['reference'] === 'true')) ? 'true' : 'false';
-                $this->config[$name]['args'][$method_name][] = $type . ':' . $ref . ':' . $text;
+                if ($method_name != '') {
+                    $type = isset($attribute['type']) ? $attribute['type'] : 'value';
+                    $ref  = (isset($attribute['reference']) && ($attribute['reference'] === 'true')) ? 'true' : 'false';
+                    $this->config[$name]['args'][$method_name][] = $type . ':' . $ref . ':' . $text;
+                }
                 break;
 
            case '/actions/action/components/component':
