@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigActionscmd.php,v 1.6 2007/01/21 08:12:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigActionscmd.php,v 1.7 2007/03/17 13:53:07 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigActionscmd.php,v 1.6 2007/01/21 08:12:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigActionscmd.php,v 1.7 2007/03/17 13:53:07 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigActionscmd extends SyL_Config
@@ -110,13 +110,13 @@ class SyL_ConfigActionscmd extends SyL_Config
      *
      * @access public
      */
-    function parseXML()
+    function parseXml()
     {
         // 
         $config = array();
         foreach ($this->file_names as $file_name) {
             parent::setFile($file_name);
-            parent::parseXML();
+            parent::parseXml();
             $config += $this->config;
             // 
             $this->config = array();
