@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorCmd.php,v 1.8 2007/02/03 11:44:45 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorCmd.php,v 1.9 2007/03/24 05:20:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,51 +39,27 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorCmd.php,v 1.8 2007/02/03 11:44:45 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorCmd.php,v 1.9 2007/03/24 05:20:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ErrorCmd extends SyL_Error
 {
     /**
-     * 顼ϥɥ顼μ
+     * Ķ̥顼
      * 
-     * @access protected
+     * @access public
+     * @param array 顼å
+     * @param array 顼ȥ졼
      */
-    function errorHandler()
+    function displayError($error_messages, $error_trace)
     {
-        // Хåե󥰥ꥢ
-        // ɬ
-        if (!headers_sent() && (ob_get_level() > 0)) {
-            ob_clean();
-        }
-
-        // 顼פμ
-        $error_type = $this->getErrorType();
         // 顼å
-        $error_message = implode($this->eof, $this->getErrorMessages()) . $this->eof;
-        // 顼ȥ졼μ
-        $error_trace = SYL_ERROR_TRACE ? $this->getTraceConsole() : '';
-        // 顼å
-        $error_string = SYL_ERROR ? "[{$error_type}] {$error_message}" : SYL_ERROR_MESSAGE;
+        $error_message = implode($this->eof, $error_messages) . $this->eof;
         // 顼åɽ
-        $this->displayErrorDefault($error_string, $error_trace);
-        // 
-        $this->logging();
-    }
-
-    /**
-     * ǥեȥ顼
-     *
-     * @access private
-     * @param string 顼å
-     * @param string 顼ȥ졼
-     */
-    function displayErrorDefault($error_string, $error_trace)
-    {
-        echo $error_string;
+        echo $error_message;
         if ($error_trace) {
             echo $this->eof;
-            echo $error_trace;
+            echo $this->getTraceConsole($error_trace);
         }
     }
 
@@ -91,30 +67,19 @@ class SyL_ErrorCmd extends SyL_Error
      * 顼ȥ졼
      *
      * @access public
+     * @return array 顼ȥ졼
      * @return string 顼ȥ졼
      */
-    function getTraceConsole()
+    function getTraceConsole($error_trace)
     {
-        $error_trace = $this->getTrace();
-        $i = count($error_trace);
         $error_trace_result = '';
-        if ($i > 0) {
+        if (count($error_trace) > 0) {
             // 顼ȥ졼ɽκ
-            $error_trace_result .= "------ start Debug Trace ------" . $this->eof;
+            $error_trace_result .= "------ start Stack Trace ------" . $this->eof;
             foreach ($error_trace as $value) {
-                if (($value['function'] == '') || ($value['function'] == 'unknown')) {
-                    $value['function'] = '';
-                }
-                if ($value['file'] == '') {
-                    $value['file'] = '-';
-                }
-                if ($value['line'] == '') {
-                    $value['line'] = '-';
-                }
-                $error_trace_result .= "{$i}. [file] {$value['file']} [line] {$value['line']} [function] {$value['function']}" . $this->eof;
-                $i--;
+                $error_trace_result .= "{$value['no']}. [file] {$value['file']} [line] {$value['line']} [function] {$value['function']}" . $this->eof;
             }
-            $error_trace_result .= "------ end Debug Trace ------" . $this->eof;
+            $error_trace_result .= "------ end Stack Trace ------" . $this->eof;
         }
 
         return $error_trace_result;
