@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterPathinfo.php,v 1.10 2007/01/28 07:13:25 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterPathinfo.php,v 1.11 2007/02/22 12:55:38 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -62,7 +62,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterPathinfo.php,v 1.10 2007/01/28 07:13:25 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterPathinfo.php,v 1.11 2007/02/22 12:55:38 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_RouterPathinfo extends SyL_Router
@@ -92,6 +92,10 @@ class SyL_RouterPathinfo extends SyL_Router
             $this->action_file = $pathinfo . $script_name;
         } else {
             $pathinfo_dir = dirname($pathinfo);
+            // windowsб
+            if ($pathinfo_dir == '\\') {
+                $pathinfo_dir = '/';
+            }
             if ($pathinfo_dir == '/') {
                 $this->action_file = '/' . $script_name;
             } else {
