@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Auth.php,v 1.1 2007/03/17 13:53:07 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Auth.php,v 1.2 2007/03/24 05:20:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Auth.php,v 1.1 2007/03/17 13:53:07 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Auth.php,v 1.2 2007/03/24 05:20:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Auth
@@ -181,7 +181,7 @@ class SyL_Auth
     function isAuthArea()
     {
         $request_uri = isset($_SERVER['REQUEST_URI']) ? $_SERVER['REQUEST_URI'] : '/';
-        return (bool)preg_match('/^' . preg_quote(SYL_AUTH_URL, '/') . '/', $request_uri);
+        return (bool)preg_match('/^' . preg_quote(SyL_Auth::getRedirectUrl(), '/') . '/', $request_uri);
     }
 
     /**
@@ -219,11 +219,11 @@ class SyL_Auth
     function isLoginPassword($client_username, $client_password, $server_password, $server_hash)
     {
         if (!$this->isLoginAction()) {
-            SyL_Loggers::warn("[Auth] Login Failed. No Login Action: class = " . get_class($this) . " user = {$client_username} hash = " . SYL_AUTH_PASSWORD_HASH);
+            SyL_Loggers::warn("[Auth] Login Failed. No Login Action. (class: " . get_class($this) . " user: {$client_username} hash: " . SYL_AUTH_PASSWORD_HASH . ")");
             return false;
         }
         if (($client_username === null) || ($client_username === '')) {
-            SyL_Loggers::warn("[Auth] Login Failed. Empty UserName: class = " . get_class($this) . " user = {$client_username} hash = " . SYL_AUTH_PASSWORD_HASH);
+            SyL_Loggers::warn("[Auth] Login Failed. Empty UserName. (class: " . get_class($this) . " user: {$client_username} hash: " . SYL_AUTH_PASSWORD_HASH . ")");
             return false;
         }
 
@@ -242,10 +242,10 @@ class SyL_Auth
 
         if ($server_password == $client_password) {
             $this->session->setParameter($this->session_name, $client_username);
-            SyL_Loggers::info("[Auth] Login Success: class = " . get_class($this) . " user = {$client_username} hash = " . SYL_AUTH_PASSWORD_HASH);
+            SyL_Loggers::info("[Auth] Login Success. (class: " . get_class($this) . " user: {$client_username} hash: " . SYL_AUTH_PASSWORD_HASH . ")");
             return true;
         } else {
-            SyL_Loggers::warn("[Auth] Login Failed. Invalid Password: class = " . get_class($this) . " user = {$client_username} hash = " . SYL_AUTH_PASSWORD_HASH);
+            SyL_Loggers::warn("[Auth] Login Failed. Invalid Password. (class: " . get_class($this) . " user: {$client_username} hash: " . SYL_AUTH_PASSWORD_HASH . ")");
             return false;
         }
     }
@@ -269,6 +269,8 @@ class SyL_Auth
      */
     function doLogout()
     {
+        $client_username = $this->session->getParameter($this->session_name);
+        SyL_Loggers::info("[Auth] Logout Success. (class: " . get_class($this) . " user: {$client_username})");
         $this->session->deleteParameters();
     }
 
@@ -306,6 +308,7 @@ class SyL_Auth
     /**
      * TOPURL
      * 
+     * @static
      * @access public
      */
     function getRedirectUrl()
@@ -313,16 +316,6 @@ class SyL_Auth
         return SYL_AUTH_URL;
     }
 
-    /**
-     * TOP̤إ쥯
-     * 
-     * @access public
-     */
-    function redirect()
-    {
-        SyL_Response::redirect(SYL_AUTH_URL);
-    }
-
     /**
      * å󥨥顼̤إ쥯
      * 
