@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DefinesReader.php,v 1.11 2007/01/21 08:12:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DefinesReader.php,v 1.12 2007/03/17 13:53:07 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Config.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DefinesReader.php,v 1.11 2007/01/21 08:12:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DefinesReader.php,v 1.12 2007/03/17 13:53:07 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DefinesReader
@@ -67,7 +67,7 @@ class SyL_DefinesReader
 
         $controller = null; // ߡ
         $config =& SyL_Config::getObject('defines', $config_files, $controller);
-        $config->parseXML();
+        $config->parseXml();
 
         // ɤ߹
         SyL_DefinesReader::readDefine($config->getConfig());
