@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Response.php,v 1.9 2007/03/17 13:53:07 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Response.php,v 1.10 2007/03/24 05:20:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Response.php,v 1.9 2007/03/17 13:53:07 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Response.php,v 1.10 2007/03/24 05:20:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Response
@@ -70,19 +70,70 @@ class SyL_Response
 
     /**
      * 쥯Ȥ
+     *
+     * RFCˤʤ٤ह褦ˡʼǤС˼ưURLåȤ
      * 
      * @static
      * @access public
      * @param string 쥯URL
      */
-    function redirect($url)
+    function redirect($url, $pathinfo=null)
     {
-        if (SYL_ENV_TYPE == 'web') {
-            SyL_Loggers::debug("[Response] Redirect -> {$url}");
-            SyL_Response::setHeader('Location', $url);
-            $obj =& SyL_Response::getInstance();
-            $obj->sendHeader();
+        if (!preg_match('/^[a-z]+:\/\/(.+)/i', $url)) {
+            $protocol = '';
+            $server   = '';
+            if (isset($_SERVER['SERVER_PORT']) && (($_SERVER['SERVER_PORT'] == '80') || ($_SERVER['SERVER_PORT'] == '443'))) {
+                $protocol = ($_SERVER['SERVER_PORT'] == '80') ? 'http' : 'https';
+            }
+            if (isset($_SERVER['HTTP_HOST'])) {
+                $server = $_SERVER['HTTP_HOST'];
+            } else if (isset($_SERVER['SERVER_NAME'])) {
+                $server = $_SERVER['SERVER_NAME'];
+            }
+
+            if ($protocol && $server) {
+                if (substr($url, 0, 1) == '/') {
+                    $url = "{$protocol}://{$server}{$url}";
+                } else {
+                    if ($pathinfo === null) {
+                        $path = '';
+                        if (($pathinfo === true) || (($pathinfo === null) && (strpos(SYL_ROUTER_RULE, 'pathinfo') !== false))) {
+                            if (isset($_SERVER['PHP_SELF'])) {
+                                $path = dirname($_SERVER['PHP_SELF']);
+                            }
+                        } else {
+                            if (isset($_SERVER["SCRIPT_NAME"])) {
+                                $path = dirname($_SERVER["SCRIPT_NAME"]);
+                            }
+                        }
+                        if ($path) {
+                            if ($path != '/') {
+                                $path .= '/';
+                            }
+                            $path .= $url;
+                            while (preg_match('/^(.+\/)([^\/]+\/\.\.\/)(.+)$/', $path, $matches)) {
+                                $path = $matches[1] . $matches[3];
+                            }
+                            $path = str_replace('./', '', $path);
+                            $url = "{$protocol}://{$server}{$path}";
+                        }
+                    }
+                }
+            }
         }
+
+        if (SYL_ENV_TYPE == 'js') {
+            // JSǻѤ硢301 ϥ֥饦٥ǥ쥯Ȥ뤿306
+            SyL_Response::setStatusHeader('306');
+            SyL_Loggers::info("[Response] Redirect(306) -> {$url}");
+        } else {
+            SyL_Response::setStatusHeader('301');
+            SyL_Loggers::info("[Response] Redirect(301) -> {$url}");
+        }
+        SyL_Response::setHeader('Location', $url);
+        $obj =& SyL_Response::getInstance();
+        $obj->sendHeader();
+
         exit;
     }
 
