@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DB.php,v 1.11 2007/03/24 05:20:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DB.php,v 1.12 2007/03/31 08:45:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DB.php,v 1.11 2007/03/24 05:20:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DB.php,v 1.12 2007/03/31 08:45:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DB
@@ -278,7 +278,7 @@ class SyL_DB
      */
     function escapeLike($parameter)
     {
-        return preg_replace('/(\_|\%)/', '\\\\$1', $this->escape($parameter));
+        return preg_replace('/(\_|\%)/', '\\\\$1', $parameter);
     }
 
     /**
@@ -294,31 +294,12 @@ class SyL_DB
         if (($value === '') || ($value === null)) {
             return 'NULL';
         } else if (is_int($value) || is_float($value)) {
-            return $value;
+            return (string)$value;
         } else {
             return "'" . $this->escape($value) . "'";
         }
     }
 
-    /**
-     * SQLʸ
-     * ˥¹Ԥ
-     *
-     * @access public
-     * @param string ̾
-     * @param string ǡ
-     * @return string SQLʸ
-     */
-    function condition($column, $value)
-    {
-        $value = $this->quote($value);
-        if ($value == 'NULL') {
-            return "$column IS $value ";
-        } else {
-            return "$column = $value ";
-        }
-    }
-
     /**
      * ȥ󥶥󳫻
      *
@@ -497,7 +478,7 @@ class SyL_DB
     /**
      * ڡ󥰥֥Ȥ
      *
-     * @access public
+     * @access protected
      * @param int 1ڡɽ
      * @param int ɽоݥڡ 
      * @return object ڡ󥰥֥
@@ -512,98 +493,30 @@ class SyL_DB
     }
 
     /**
-     * Υѥ᡼ˡSQLDMLˤȤΩƼ¹Ԥ
-     * ˥⼫ưǹԤ
-     * ѿǻꤹʳϡȽꤵ롣
-     *
-     * array(
-     *  'name'     => $name,
-     *  'address'  => $adress,
-     *  'datetime' => array('function' => 'current_timestamp'),
-     *  'id'       => array('number' => 1),
-     *  'IS_NULL'  => array('null' => ''),
-     *  ...
-     * );
+     * SQLۥ饹
      *
      * @access public
-     * @param string ơ֥̾
-     * @param array ȤΥǡ
-     * @param string insert or update or delete
-     * @param string ѥ᡼update, deleteΤߡ
-     * @return bool ¹Է true: OKfalse: 顼
+     * @return object SQLۥ֥
      */
-    function execPerform($table, $columns, $action='insert', $where='')
+    function &createBuilder()
     {
-        switch (strtolower($action)) {
-        case 'insert':
-            $field = array();
-            $data  = array();
-            foreach ($columns as $column => $value) {
-                $field[] = $column;
-                if (is_array($value)) {
-                    list($attribute, $value) = each($value);
-                    if ((strtolower($attribute) === 'null') || ($value === null) || ($value === '')) {
-                        $data[] = "NULL";
-                    } else {
-                        switch (strtolower($attribute)) {
-                        case 'function':
-                        case 'number':
-                            $data[] = $value;
-                            break;
-                        default:
-                            $data[] = $this->quote($value);
-                            break;
-                        }
-                    }
-                } else {
-                    $data[] = $this->quote($value);
-                }
-            }
-            // SQL INSERT
-            $sql = "INSERT INTO " . $table . " (" . implode(',', $field) . ") VALUES (" . implode(',', $data) . ")";
-            break;
-
-        case 'update':
-            $update = array();
-            foreach ($columns as $column => $value) {
-                if (is_array($value)) {
-                    list($attribute, $value) = each($value);
-                    if ((strtolower($attribute) === 'null') || ($value === null) || ($value === '')) {
-                        $update[] = $column . " = NULL";
-                    } else {
-                        switch (strtolower($attribute)) {
-                        case 'function':
-                        case 'number':
-                            $update[] = $column . " = " . $value;
-                            break;
-                        default:
-                            $update[] = $column . " = " . $this->quote($value);
-                            break;
-                        }
-                    }
-                } else {
-                    $update[] = $column . " = " . $this->quote($value);
-                }
-            }
-      
-            if ($where != '') {
-                $where = "WHERE " . $where;
-            }
-            // SQL UPDATE
-            $sql = "UPDATE " . $table . " SET " . implode(',', $update) . " " . $where;
-            break;
-
-        case 'delete':
-            if ($where != '') {
-                $where = "WHERE " . $where;
-            }
-            // SQL DELETE
-            $sql = "DELETE FROM " . $table . " " . $where;
-
-        default:
-          trigger_error("[SyL error] queryPerform method is insert or update or delete only", E_USER_ERROR);
-        }
+        include_once dirname(__FILE__) . '/Sql/SyL_SqlBuilder.php';
+        $builder =& new SyL_SQLBuilder($this);
+        return $builder;
+    }
 
+    /**
+     * SQLۥ饹SQL¹Ԥ
+     *
+     * @access public
+     * @param object SQLۥ֥
+     * @param string select or insert or update or delete
+     * @return mixed ¹Է
+     */
+    function execBuilder(&$builder, $action='select')
+    {
+        $func = 'getStatement' . ucfirst($action);
+        $sql  = call_user_func(array(&$builder, $func));
         return $this->exec($sql);
     }
 
