@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Validation.php,v 1.8 2007/01/21 08:13:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Validation.php,v 1.9 2007/03/31 08:45:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -35,11 +35,11 @@
 /**
  * ڸ̥饹
  */
-require_once dirname(__FILE__) . DIRECTORY_SEPARATOR . 'Validation' . DIRECTORY_SEPARATOR . 'SyL_Validator.php';
+require_once dirname(__FILE__) . '/Validation/SyL_ValidationValidator.php';
 /**
  * ڸ̥롼ץ饹
  */
-require_once dirname(__FILE__) . DIRECTORY_SEPARATOR . 'Validation' . DIRECTORY_SEPARATOR . 'SyL_Validators.php';
+require_once dirname(__FILE__) . '/Validation/SyL_ValidationValidators.php';
 
 /**
  * ڥ饹
@@ -48,7 +48,7 @@ require_once dirname(__FILE__) . DIRECTORY_SEPARATOR . 'Validation' . DIRECTORY_
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Validation.php,v 1.8 2007/01/21 08:13:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Validation.php,v 1.9 2007/03/31 08:45:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Validation
@@ -68,9 +68,34 @@ class SyL_Validation
      * @param string ̾
      * @return string 顼å
      */
-    function getErrorMessage($name='')
+    function getErrorMessage()
+    {
+        return $this->error_message;
+    }
+
+    /**
+     * 顼å
+     *
+     * @access public
+     * @param string ̾
+     */
+    function replaceErrorMessage($name)
+    {
+        if ($name) {
+            $this->error_message = str_replace('{name}', $name, $this->error_message);
+        }
+    }
+
+    /**
+     * ڽ¹Ԥ
+     *
+     * @access public
+     * @param string о
+     * @param string о̾
+     * @return bool true: 顼̵, false: 顼
+     */
+    function execute($value, $name='')
     {
-        return (($name != '') ? str_replace('{name}', $name, $this->error_message) : $this->error_message);
     }
 
     /**
@@ -81,18 +106,7 @@ class SyL_Validation
      */
     function isRequire()
     {
-        return preg_match('/^SyL_Validator(Requires?)(.*)$/i', get_class($this));
-    }
-
-    /**
-     * ڽ¹Ԥ
-     *
-     * @access public
-     * @param string о
-     * @return bool true: 顼̵, false: 顼
-     */
-    function execute($value)
-    {
+        return preg_match('/^SyL_ValidationValidatorRequire(.*)$/i', get_class($this));
     }
 
     /**
